@@ -3,10 +3,13 @@ Exports the libgeos_c shared lib, GEOS-specific exceptions, and utilities.
 """
 
 import atexit
-import os
-import sys
 from ctypes import cdll, CDLL, PyDLL, CFUNCTYPE, c_char_p
 from ctypes.util import find_library
+import os
+import sys
+
+from ctypes_declarations import prototype
+
 
 if sys.platform == 'win32':
     try:
@@ -50,15 +53,14 @@ else:
         raise
     free = CDLL('libc.so.6').free
 
+# Prototype the libgeos_c functions using new code from `tarley` in
+# http://trac.gispython.org/lab/ticket/189
+prototype(lgeos)
 
-# Load the ctypes restype and argtype declarations for geos_c functions.
-_here = os.path.abspath(os.path.dirname(__file__))
-execfile(os.path.join(_here, 'ctypes_declarations.py'))
 
 class allocated_c_char_p(c_char_p):
     pass
 
-
 # Exceptions
 
 class ReadingError(Exception):
